/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _GroupPane_h_
#define _GroupPane_h_

#include <gtk/gtk.h>
#include <pan/general/quark.h>
#include <pan/data/data.h>
#include <pan/gui/action-manager.h>

namespace pan
{
  /**
   * Group Pane in the main window of Pan's GUI.
   * @ingroup GUI
   */
  class GroupPane: private Data::Listener
  {
    protected: // Data::Listener
      virtual void on_grouplist_rebuilt ();
      virtual void on_group_read (const Quark& group);
      virtual void on_group_subscribe (const Quark& group, bool sub);
      virtual void on_group_counts (const Quark& group, ulong unread, ulong total);

    public:
      GroupPane (ActionManager&, Data&);
      ~GroupPane ();
      GtkWidget* root () { return _root; }
      void set_name_collapse (bool);
      Quark get_selection () const;
      quarks_t get_full_selection () const;

    private:
      Data& _data;
      bool _collapsed;
      GtkWidget * _root;
      GtkWidget * _tree_view;
      GtkWidget * _toolbar_bin;
      GtkTreeStore * _tree_store;
      quarks_t groups_in_model;

    private:
      static void do_popup_menu (GtkWidget*, GdkEventButton*, gpointer);
      static gboolean on_button_pressed (GtkWidget*, GdkEventButton*, gpointer);
      static gboolean on_popup_menu (GtkWidget*, gpointer);
      static void on_row_activated (GtkTreeView*, GtkTreePath*, GtkTreeViewColumn*, gpointer);

    public: // pretend these are private
      void set_filter (const std::string& text);
      const ActionManager& _action_manager;
  };
}

#endif
